#
# spec file for package python-pytest-astropy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-astropy
Version:        0.11.0
Release:        1.10
Summary:        Meta-package containing dependencies for testing
License:        BSD-3-Clause
URL:            https://github.com/astropy/pytest-astropy
Source:         https://files.pythonhosted.org/packages/source/p/pytest-astropy/pytest-astropy-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2.0
Requires:       python-hypothesis >= 5.1
Requires:       python-pytest >= 4.6
Requires:       python-pytest-arraydiff >= 0.5
Requires:       python-pytest-astropy-header >= 0.2.2
Requires:       python-pytest-cov >= 2.3.1
Requires:       python-pytest-doctestplus >= 1.0.0
Requires:       python-pytest-filter-subpackage >= 0.1.2
Requires:       python-pytest-mock >= 2.0
Requires:       python-pytest-remotedata >= 0.4.1
BuildArch:      noarch
%python_subpackages

%description
This is a meta-package that pulls in the dependencies that are used by
astropy and some affiliated packages for testing. It can also be used for
testing packages that are not affiliated with the Astropy project.

This package also provides pytest markers for cpu and memory intensive tests
(`pytest.mark.slow` and `pytest.mark.hugemem`). Tests marked with those
markers are not run by default, can be run with the other tests with
`--run-slow` and `--run-hugemem`, and can be run separately with `-m slow`
and `-m hugemem`.

%prep
%setup -q -n pytest-astropy-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE.rst
%{python_sitelib}/pytest_astropy
%{python_sitelib}/pytest_astropy-%{version}.dist-info

%changelog
* Wed Oct  4 2023 Ben Greiner <code@bnavigator.de>
- The sle15_python_module_pythons needs to sit on top of the first
  use of python_module.
- Move to PEP517
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * Dropped ``pytest-openfiles`` as dependency. If you still use
    it, you can install it separately.
  * ``-R`` is added as a short version for the command-line
    option ``--remote-data``. [#55]
  * Require ``pytest-doctestplus`` 1.0.0 or later. [#56]
  * Require ``pytest-remotedata`` 0.4.1 or later. [#56]
  * Require ``pytest-astropy-header`` 0.2.2 or later. [#56]
  * Require ``pytest-arraydiff`` 0.5 or later. [#56]
  * Require ``pytest-filter-subpackage`` 0.1.2 or later. [#56]
* Thu May 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.10:
  * MNT: Stop using distutils by @pllim in #47
  * Add plugin for cpu/memory intensive tests by @saimn in #48
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.9:
  * Added ``pytest-mock`` as dependency. [#31]
  * Require ``pytest-cov`` 2.3.1 or later. [#41]
  * Require ``pytest-doctestplus`` 0.11.0 or later. [#43]
  * Dropped support for Python 3.6. [#43]
* Fri May 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Mon Mar 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- UPdate to 0.8.0:
  * Added pytest-filter-subpackage and pytest-cov as dependencies. [#29]
  * Dropped support for Python 2.7 and 3.5. [#29]
  * Require Hypothesis 5.1 or later. [#29]
* Wed Dec 18 2019 Benjamin Greiner <code@bnavigator.de>
- Update to 0.7.0
  * requires new pytest-astropy-header (Request 755857)
  * Python 3 only
* Fri Feb 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.0:
  * Just updates in metadata
* Tue Aug 14 2018 toddrme2178@gmail.com
- Initial version
